'''Main module of marionette-predeployed

Classes:
  - UpgradeableMarionetteGenerator

Values:
  - MARIONETTE_ADDRESS
  - MARIONETTE_IMPLEMENTATION_ADDRESS
'''

from .address import MARIONETTE_ADDRESS, MARIONETTE_IMPLEMENTATION_ADDRESS
from .upgradeable_marionette_generator import UpgradeableMarionetteGenerator
